@@ -1,7 +1,7 @@
 /***************************************************************************
  begin       : Mon Mar 01 2004
  copyright   : (C) 2018 by Martin Preuss
- email       : martin@libchipcard.de
+ email       : martin at libchipcard.de
 
  ***************************************************************************
  *          Please see toplevel file COPYING for license details           *
